@@ -17,7 +17,7 @@ import Data.Function as X (const, flip, id, on, ($), (&), (.))
 import Data.Functor as X (Functor (..), void, ($>), (<$), (<$>))
 import Data.List.NonEmpty as X (NonEmpty (..))
 import Data.Map as X (Map)
-import Data.Maybe as X (Maybe (..), catMaybes, maybe)
+import Data.Maybe as X (Maybe (..), catMaybes, fromMaybe, maybe)
 import Data.Monoid as X (Monoid (..))
 import Data.Ord as X (Ord (..), Ordering (..), max, min)
 import Data.Semigroup as X (Semigroup (..))
